%define major		22
%define	api		2.0
%define libname         %mklibname %{name} %{api} %{major}
%define develname	%mklibname %{name} -d

%define rlmajor		18
%define rlapi		18
%define rllibname	%mklibname %{name}readline %{rlapi} %{rlmajor}

Summary:	GNU implementation of Scheme for application extensibility
Name:		guile
Version:	2.0.5
Release:	3
License:	LGPLv2+
Group:		Development/Other
URL:		http://www.gnu.org/software/guile/guile.html
Source0:	ftp://ftp.gnu.org/pub/gnu/guile/guile-%{version}.tar.xz
Source1:	%{SOURCE0}.sig
Patch0:		guile-2.0.3-64bit-fixes.patch
Patch1:		guile-2.0.3-drop-ldflags-from-pkgconfig.patch
Patch3:		guile-2.0.5-turn-off-gc-test.patch
Patch4:		guile-2.0.3-mktemp.patch

BuildRequires:	chrpath
# for srfi-19.test
BuildRequires:	timezone
BuildRequires:	gettext-devel
BuildRequires:	gmp-devel
BuildRequires:	libtool-devel
BuildRequires:	ncurses-devel
BuildRequires:	readline-devel
BuildRequires:	pkgconfig(bdw-gc)

%description
GUILE (GNU's Ubiquitous Intelligent Language for Extension) is a
library implementation of the Scheme programming language, written in
C. GUILE provides a machine-independent execution platform that can
be linked in as a library during the building of extensible programs.

Install the guile package if you'd like to add extensibility to
programs that you are developing. You'll also need to install the
guile-devel package.

%package -n %{libname}
Summary:	Libraries for Guile %{version}
Group:		System/Libraries
Requires:	%{name}-runtime = %{version}-%{release}

%description -n %{libname}
This package contains Guile shared object libraries.

%package -n %{rllibname}
Summary:	Libraries for Guile %{version}
Group:		System/Libraries

%description -n %{rllibname}
This package contains Guile shared object libraries.

%package -n %{develname}
Summary:	Development headers and static library for libguile
Group:		Development/C
Requires:	%{name} >= %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	%{rllibname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains the development headers and the static library
for libguile. C headers, aclocal macros, the `guile1.4-snarf' and
`guile-config' utilities, and static `libguile' library for Guile, the
GNU Ubiquitous Intelligent Language for Extension

%package runtime
Summary:        Guile runtime library
Group:          System/Libraries
Conflicts:	%{name} < 2.0.5-1

%description runtime
This package contains Scheme runtime for GUILE, including ice-9
Scheme module.

%prep
%setup -q
%apply_patches

#fix encodings
for i in libguile/ChangeLog*; do
	mv $i $i.old
	iconv -f ISO8859-1 -t UTF-8 $i.old -o $i
done

%build
autoreconf -vfi
%configure2_5x \
	--disable-error-on-warning \
	--disable-rpath \
	--disable-static \
	--with-threads \
	--with-pic

%make

%install
%makeinstall_std

#remove rpath
chrpath -d %{buildroot}%{_bindir}/%{name}

#we don't want these
find %{buildroot} -name "*.la" -delete

#for ghost files
touch %{buildroot}%{_datadir}/%{name}/%{api}/slibcat
touch %{buildroot}%{_datadir}/%{name}/%{api}/slib

#slib needs this
mkdir -p %{buildroot}%{_datadir}/guile/site

%if 0
%check
%make check
%endif

%post
%_install_info %{name}-tut.info
%_install_info %{name}.info
%_install_info r5rs.info
%_install_info goops.info

%preun
%_remove_install_info %{name}-tut.info
%_remove_install_info %{name}.info
%_remove_install_info r5rs.info
%_remove_install_info goops.info

%triggerin -- slib
ln -sfT ../../slib %{_datadir}/guile/%{api}/slib

rm -f %{_datadir}/guile/%{mver}/slibcat
export SCHEME_LIBRARY_PATH=%{_datadir}/slib/

# Build SLIB catalog
for pre in \
    "(use-modules (ice-9 slib))" \
    "(load \"%{_datadir}/slib/guile.init\")"
do
    %{_bindir}/guile -c "$pre
        (set! implementation-vicinity (lambda () \"%{_datadir}/guile/%{api}/\"))
        (require 'new-catalog)" &> /dev/null && break
    rm -f %{_datadir}/guile/%{api}/slibcat
done
:

%triggerun -- slib
if [ "$1" = 0 -o "$2" = 0 ]; then
    rm -f %{_datadir}/guile/%{api}/slib{,cat}
fi

%files
%doc AUTHORS ChangeLog GUILE-VERSION LICENSE README THANKS
%{_bindir}/%{name}
%{_bindir}/%{name}-tools
%{_bindir}/guild
%{_libdir}/%{name}
%exclude %{_libdir}/%{name}/%{api}
%{_datadir}/%{name}
%exclude %{_datadir}/%{name}/%{api}
%{_mandir}/man1/guile.1.*
%{_infodir}/*

%files -n %{libname}
%{_libdir}/lib%{name}-%{api}.so.%{major}*

%files -n %{rllibname}
%{_libdir}/lib%{name}readline-v-%{rlapi}.so.%{rlmajor}*

%files -n %{develname}
%doc HACKING NEWS libguile/ChangeLog*
%{_bindir}/%{name}-config
%{_bindir}/%{name}-snarf
%{_datadir}/aclocal/*
%{_includedir}/%{name}
%{_libdir}/lib%{name}-%{api}.so
%{_libdir}/lib%{name}readline-v-%{rlapi}.so
%{_libdir}/pkgconfig/%{name}*.pc

%files runtime
%{_libdir}/%{name}/%{api}/*
%{_datadir}/%{name}/%{api}/*.scm
%{_datadir}/%{name}/%{api}/*.txt
%{_datadir}/%{name}/%{api}/ice-9/*
%{_datadir}/%{name}/%{api}/language/*
%{_datadir}/%{name}/%{api}/oop/*
%{_datadir}/%{name}/%{api}/rnrs/*
%{_datadir}/%{name}/%{api}/scripts/*
%{_datadir}/%{name}/%{api}/srfi/*
%{_datadir}/%{name}/%{api}/sxml/*
%{_datadir}/%{name}/%{api}/system/*
%{_datadir}/%{name}/%{api}/texinfo/*
%{_datadir}/%{name}/%{api}/web/*
%ghost %{_datadir}/%{name}/%{api}/slibcat
%ghost %{_datadir}/%{name}/%{api}/slib



%changelog
* Thu May 17 2012 Matthew Dawkins <mattydaw@mandriva.org> 2.0.5-3
+ Revision: 799440
- make devel pkg require the main bin

* Tue May 08 2012 Matthew Dawkins <mattydaw@mandriva.org> 2.0.5-2
+ Revision: 797343
- rebuild to fix runtime and main pkg conflicts

* Sun May 06 2012 Matthew Dawkins <mattydaw@mandriva.org> 2.0.5-1
+ Revision: 796947
- new version 2.0.5
- reimported spec from mga (with major clean ups)
- patchset sync'd with mga

* Mon Dec 19 2011 Andrey Bondrov <abondrov@mandriva.org> 1.8.8-3
+ Revision: 743810
- Rebuild to remove .la files, spec cleanup

* Mon May 02 2011 Oden Eriksson <oeriksson@mandriva.com> 1.8.8-2
+ Revision: 661670
- multiarch fixes

* Mon Apr 11 2011 Funda Wang <fwang@mandriva.org> 1.8.8-1
+ Revision: 652632
- new version 1.8.8

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuild

* Thu Feb 18 2010 Frederic Crozat <fcrozat@mandriva.com> 1.8.7-4mdv2010.1
+ Revision: 507813
- Move slib registration to versioned directory (sync with Fedora)
- run autoreconf at setup time, not build time

* Tue Feb 09 2010 Funda Wang <fwang@mandriva.org> 1.8.7-3mdv2010.1
+ Revision: 502947
- add fedora testsuite2 patch
- rebuild for new gmp

* Sun Nov 15 2009 Funda Wang <fwang@mandriva.org> 1.8.7-2mdv2010.1
+ Revision: 466127
- fix testsuite
- new version 1.8.7

* Wed Oct 07 2009 Thierry Vignaud <tv@mandriva.org> 1.8.6-4mdv2010.0
+ Revision: 455514
- move huge NEWS in devel package

* Wed Feb 25 2009 Thierry Vignaud <tv@mandriva.org> 1.8.6-3mdv2009.1
+ Revision: 344659
- rebuild for new libreadline

* Tue Jan 27 2009 Funda Wang <fwang@mandriva.org> 1.8.6-2mdv2009.1
+ Revision: 334494
- rebuild for new libtool

* Fri Dec 26 2008 Funda Wang <fwang@mandriva.org> 1.8.6-1mdv2009.1
+ Revision: 319293
- New version 1.8.6

* Sun Dec 21 2008 Funda Wang <fwang@mandriva.org> 1.8.5-2mdv2009.1
+ Revision: 317103
- drop LDFLAGS from pkgconfig file

* Fri Sep 05 2008 Emmanuel Andry <eandry@mandriva.org> 1.8.5-1mdv2009.0
+ Revision: 281322
- fix file list
- New version
- check major
- update file list

* Mon Jun 09 2008 Pixel <pixel@mandriva.com> 1.8.3-2mdv2009.0
+ Revision: 217186
- do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <blino@mandriva.org>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Nov 28 2007 Frederic Crozat <fcrozat@mandriva.com> 1.8.3-2mdv2008.1
+ Revision: 113733
- Remove patch2 and dependency on umb-scheme (deprecated)
- add triggers for slib support (fedora)

* Wed Nov 07 2007 Adam Williamson <awilliamson@mandriva.org> 1.8.3-1mdv2008.1
+ Revision: 106629
- BUGS doesn't exist any more...
- rediff 64bit-fixes.patch and slib.patch
- drop srfi-14-test.patch and rational.patch (merged upstream)
- move docs out of lib package (per lib policy)
- new devel policy
- new license policy
- new version 1.8.3


* Mon Jan 08 2007 Götz Waschk <waschk@mandriva.org> 1.8.1-7mdv2007.0
+ Revision: 105967
- bot rebuild

  + Michael Scherer <misc@mandriva.org>
    - rebuild
    - use %%rel scheme for %%mkrel
    - use fedora patch, to fix a gnucash crash, reported by goetz
      <unnamed port>: In expression (user-vicinity):
      <unnamed port>: Unbound variable: user-vicinity
      I do not really understand why the previous patch was wrong, but i am not
      a lisp master. This one comes from fedora packages, and work well with
      gnucash.

* Sun Jan 07 2007 David Walluck <walluck@mandriva.org> 1.8.1-5mdv2007.1
+ Revision: 105149
- devel package Requires: libgmp-devel

* Sun Jan 07 2007 David Walluck <walluck@mandriva.org> 1.8.1-4mdv2007.1
+ Revision: 105126
- remove references to libqthreads
- BuildRequires: libgmp-devel
  add rational patch for lilypond
- add slib patch
- 1.8.1

  + Bruno Cornec <Bruno.Cornec@mandriva.org>
    - import guile-1.6.8-3mdv2007.0

* Wed Aug 09 2006 Gtz Waschk <waschk@mandriva.org> 1.6.8-3mdv2007.0
- add slib symlink
- bump umb-scheme dep

* Tue Aug 08 2006 Gtz Waschk <waschk@mandriva.org> 1.6.8-2mdv2007.0
- fix post installation script

* Tue Aug 08 2006 Gtz Waschk <waschk@mandriva.org> 1.6.8-1mdv2007.0
- New release 1.6.8

* Wed Mar 08 2006 Michael Scherer <misc@mandriva.org> 1.6.7-9mdk
- fix requires on x86_64 ( no quick thread )
- do use file based requires

* Wed Jan 18 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 1.6.7-8mdk
- fix build for x86-64 - no qthreads

* Wed Oct 12 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 1.6.7-7mdk
- fix file list and deps for ppc - no quickthreads

* Fri Aug 26 2005 Abel Cheung <deaddog@mandriva.org> 1.6.7-6mdk
- Move some .so symlinks to main package as they are dynamically loaded
  by *.scm files (#13837)
- Prereq -> Requires (#17444)

* Sun Aug 21 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 1.6.7-5mdk
- add BuildRequires: libltdl-devel

* Sat Aug 20 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 1.6.7-4mdk
- gcc4 fixes

* Thu Feb 03 2005 Abel Cheung <deaddog@mandrake.org> 1.6.7-3mdk
- multiarch
- Fix info-install requirement

* Fri Jan 21 2005 Gtz Waschk <waschk@linux-mandrake.com> 1.6.7-2mdk
- rebuild for new readline

* Sun Dec 26 2004 Abel Cheung <deaddog@mandrake.org> 1.6.7-1mdk
- New release
- Use tar.gz (with signature)
- Move shared files out of lib package, allowing multilib

